==> systemsettings_5.12.4.orig.tar.xz: systemsettings-5.12.4/app/SystemSettingsApp.cpp <==
/**
 * Copyright (C) 2009 Ben Cooksley <bcooksley@kde.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "SystemSettingsApp.h"
#include <kdbusservice.h>
#include <KWindowSystem>

SystemSettingsApp::SystemSettingsApp(int& argc, char* argv[])
    : QApplication(argc, argv)
    , window(0)
{
    setOrganizationDomain("kde.org");
    KDBusService* service = new KDBusService(KDBusService::Unique, this);
    QObject::connect(service, &KDBusService::activateRequested, this, [=]() {
        KWindowSystem::forceActiveWindow(window->winId());
    } );
}

SystemSettingsApp::~SystemSettingsApp()
{
}

void SystemSettingsApp::setMainWindow(SettingsBase * main)
{
    window = main;
}

void SystemSettingsApp::quit()
{
    if( window && !window->queryClose() ) {
        return;
    }
    QApplication::quit();
}

==> systemsettings-5.13.0.tar.xz: systemsettings-5.13.0/app/SystemSettingsApp.cpp <==
/**
 * Copyright (C) 2009 Ben Cooksley <bcooksley@kde.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "SystemSettingsApp.h"
#include <kdbusservice.h>
#include <KWindowSystem>

SystemSettingsApp::SystemSettingsApp(int& argc, char* argv[])
    : QApplication(argc, argv)
{
    setOrganizationDomain(QStringLiteral("kde.org"));
    KDBusService* service = new KDBusService(KDBusService::Unique, this);
    QObject::connect(service, &KDBusService::activateRequested, this, [=]() {
        KWindowSystem::forceActiveWindow(window->winId());
    } );
}

SystemSettingsApp::~SystemSettingsApp()
{
}

void SystemSettingsApp::setMainWindow(SettingsBase * main)
{
    window = main;
}

void SystemSettingsApp::quit()
{
    if( window && !window->queryClose() ) {
        return;
    }
    QApplication::quit();
}
